"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reactPureCheck = require("react-pure-check");

var _functionComUtils = require("function-com-utils");

var _operationUtils = require("operation-utils");

var HttpAuth = function HttpAuth() {
  var ajaxRes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var statusKey = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'code';
  var messageKey = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'message';
  var dataKey = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'data';

  if ((0, _reactPureCheck.Types)(ajaxRes) !== "object") {
    (0, _functionComUtils.errorLog)("you should offer a %s for ajaxRes at least", "object");
    return false;
  }
  var status = ajaxRes[statusKey] * 1;
  switch (status) {
    case 0:
    case 1:
    case 200:
      return ajaxRes.hasOwnProperty(dataKey) ? ajaxRes[dataKey] : {};
    case -1:
    default:
      (0, _operationUtils.TopMessage)().pushMessage(ajaxRes[messageKey] || "接口异常", "error");
      return false;
  }
};
/**
 * Http auth module defination
 * Author : chenchao
 * Date : 2019-07-12
 *
 * Http auth module would offer you basic auth of your ajax result .
 * 
 * But remeber , you should rewrite this module when use Http module
 *
 * @param {Object} [ajaxRes] ajax result 
 * 
 * @param {String} [statusKey] ajax status keyname reset , default is `code`
 *
 * @param {String} [messageKey] ajax status message keyname reset , default is `msg`
 * 
 * @param {String} [dataKey] ajax data keyname reset , default is `data`
 *
 */

exports.default = HttpAuth;